extends RigidBody2D

var selected = false
var is_last_selected = false
var last_connection = null

var monster_shape
var monster_handler

func _ready():
	monster_handler = get_parent()
	monster_shape = $Sprite
	pass

func _physics_process(delta):
	update()

func _draw():
	if selected:
		draw_circle(monster_shape.position, 40, Color(1, 1, 1))
		
	if is_last_selected:
		var mouse_pos = monster_shape.get_local_mouse_position() * monster_shape.scale.x
		var distance = monster_shape.position.distance_to(mouse_pos)
		var thickness  = clamp(5000/distance, 30, 50)
		draw_line(monster_shape.position, mouse_pos.clamped(200), Color(1, 1, 1), thickness)
		
	if last_connection:
		draw_line(monster_shape.position, to_local(last_connection.monster_shape.global_position), Color(1, 1, 1), 30)


func _on_RigidBody2D_input_event(viewport, event, shape_idx):
	print(event)
	
	#comment this to "fix" the bug
#	if event is InputEventMouseMotion and event.relative == Vector2() and event.speed == Vector2():
#		return
	
	if event is InputEventMouseButton:
		if event.pressed: # Clicked on monster
			monster_handler.select_monster(self)
			selected = true
			wiggle()
		
	# Also selects when entering node while draging from the outside
	elif event is InputEventMouseMotion and Input.get_mouse_button_mask() == BUTTON_LEFT and not selected:
		if monster_handler.monster_chain.empty():
			monster_handler.select_monster(self)
			selected = true
			wiggle()


func _on_RigidBody2D_mouse_entered():
	if selected and monster_handler.monster_chain.size() > 1:
		if monster_handler.monster_chain[-2] == self:
			# Deselect the last monster from the monster chain
			monster_handler.monster_chain.back().get_node("Sprite").modulate = Color(1, 1, 1, 1)
			monster_handler.monster_chain.back().selected = false
			monster_handler.monster_chain.back().is_last_selected = false
			monster_handler.monster_chain.back().last_connection = null
			monster_handler.monster_chain.pop_back()
			
			# Select the current one again
			monster_handler.select_monster(self)
			self.is_last_selected = true
			self.selected = true
	
	elif !monster_handler.monster_chain.empty():
		monster_handler.select_monster(self)
		selected = true
		wiggle()


func wiggle():
	if not $Tween.is_active():
		var end_value = monster_shape.scale.x
		var initial_value_x = end_value * 1.5
		var initial_value_y = end_value * 0.5
		
		$Tween.interpolate_property(monster_shape, "scale", Vector2(initial_value_x,initial_value_y), Vector2(end_value, end_value), 1.0,Tween.TRANS_ELASTIC,Tween.EASE_OUT)
		$Tween.start()
	else:
		$Tween.reset_all()
